@@ -11,7 +11,7 @@
 				$_SESSION["admin_actionlog_size"] = $this->model->get_log_size();
 			}
 
-			$paging = new pagination($this->output, "admin_actionlog", ADMIN_PAGE_SIZE, $_SESSION["admin_actionlog_size"]);
+			$paging = new pagination($this->output, "admin_actionlog", $this->settings->admin_page_size, $_SESSION["admin_actionlog_size"]);
 
 			if (($log = $this->model->get_action_log($paging->offset, $paging->size)) === false) {
 				$this->output->add_tag("result", "Error reading action log.");
