@@ -1,7 +1,7 @@
 <?php
 	class login_controller extends controller {
 		public function execute() {
-			$this->output->set_layout("layout_site");
+			$this->output->set_layout(LAYOUT_SITE);
 
 			$this->output->add_tag("url", $_SERVER["REQUEST_URI"]);
 			if ($_SERVER["REQUEST_METHOD"] != "POST") {
