@@ -3,7 +3,7 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 */
 
 	class MySQLi_connection extends database_connection {
@@ -13,13 +13,16 @@
 			$this->db_escape_string = array($this, "db_escape_string_wrapper");
 			$this->db_query         = array($this, "db_query_wrapper");
 			$this->db_fetch         = "mysqli_fetch_assoc";
+			$this->db_free_result   = "mysqli_free_result";
 			$this->db_affected_rows = "mysqli_affected_rows";
 			$this->db_error         = "mysqli_error";
 			$this->db_errno         = "mysqli_errno";
 			$this->id_delim         = "`";
 
-			if (($this->link = mysqli_connect($hostname, $username, $password, $database, $port)) == false) {
-				$this->link = null;
+			if ($database != "") {
+				if (($this->link = mysqli_connect($hostname, $username, $password, $database, $port)) == false) {
+					$this->link = null;
+				}
 			}
 		}
 
