@@ -49,8 +49,8 @@
 			if (($pos = strrpos($page, ".")) !== false) {
 				$page = substr($page, 0, $pos);
 			}
-		} else foreach ($page as &$item) {
-			$item = page_to_module($item);
+		} else foreach ($page as $i => $item) {
+			$page[$i] = page_to_module($item);
 		}
 
 		return $page;
@@ -69,8 +69,8 @@
 			} else {
 				$page = "";
 			}
-		} else foreach ($page as &$item) {
-			$item = page_to_type($item);
+		} else foreach ($page as $item) {
+			$page[$i] = page_to_type($item);
 		}
 
 		return $page;
