@@ -52,8 +52,8 @@
 			switch ($method) {
 				case "POST":
 					if (is_array($body)) {
-						foreach ($body as $key => &$value) {
-							$value = urlencode($key)."=".urlencode($value);
+						foreach ($body as $key => $value) {
+							$body[$key] = urlencode($key)."=".urlencode($value);
 						}
 						$body = implode("&", $body);
 					}
