@@ -84,6 +84,30 @@
 			}
 		}
 
+		/* Remove unprintable characters from string
+		 *
+		 * INPUT:  string text[, string replacement character]
+		 * OUTPUT: string text
+		 * ERROR:  -
+		 */
+		public function secure_string($str, $replace = " ") {
+			$result = "";
+
+			$len = strlen($str);
+			for ($i = 0; $i < $len; $i++) {
+				$value = ord($str[$i]);
+				if (($value == 0x9) || ($value == 0xA) || ($value == 0xD) ||
+				   (($value >= 0x20) && ($value <= 0xD7FF)) || (($value >= 0xE000) && ($value <= 0xFFFD)) ||
+				   (($value >= 0x10000) && ($value <= 0x10FFFF))) {
+					$result .= $str[$i];
+				} else {
+					$result .= $replace;
+				}
+			}
+
+			return $result;
+		}
+
 		/* Add open-tag to buffer
 		 *
 		 * INPUT:  string tag name, array( string attributes[, ...] )
