@@ -1,14 +1,14 @@
 <?php
 	$url = ltrim($_page->url, "/");
-	if (in_array($url, array("", "login", "logout")) == false) {
+	if (in_array($url, array("", LOGIN_MODULE, LOGOUT_MODULE)) == false) {
 		$next_page = $url;
 	} else {
-		$next_page = PAGE_AFTER_LOGIN;
+		$next_page = $_settings->page_after_login;
 	}
 
 	if ($_user->logged_in) {
 		$_page->select_module($next_page);
-		if ($_page->module != "login") {
+		if ($_page->module != LOGIN_MODULE) {
 			if (file_exists($file = "../models/".$_page->module.".php")) {
 				include($file);
 			}
@@ -23,7 +23,7 @@
 			$_SERVER["REQUEST_METHOD"] = "GET";
 
 			$_page->select_module($next_page);
-			if ($_page->module != "login") {
+			if ($_page->module != LOGIN_MODULE) {
 				if (file_exists($file = "../models/".$_page->module.".php")) {
 					include($file);
 				}
@@ -36,7 +36,7 @@
 		 */
 		if ($_user->login_one_time_key($_GET["login"])) {
 			$_page->select_module($next_page);
-			if ($_page->module != "login") {
+			if ($_page->module != LOGIN_MODULE) {
 				if (file_exists($file = "../models/".$_page->module.".php")) {
 					include($file);
 				}
