@@ -1,10 +1,6 @@
 <?php
-	class table_manager extends tablemanager {
-		protected $name = "Table";
+	class XXX_model extends tablemanager_model {
 		protected $table = "table";
-		protected $pathinfo_offset = 1;
-		protected $back = "back";
-		protected $icon = "table.png";
 		protected $elements = array(
 			"number" => array(
 				"label"    => "Number",
@@ -34,6 +30,13 @@
 				"options"   => array(
 					"value1" => "Value one",
 					"value2" => "Value two",
-					"value3" => "Value three")));
+					"value3" => "Value three")),
+			"foreignkey" => array(
+				"label"    => "Foreign key",
+				"type"     => "foreignkey",
+				"table"    => "table",
+				"column"   => "column",
+				"overview" => true,
+				"required" => false));
 	}
 ?>
